@@ -1,4 +1,4 @@
-subroutine isolab(g,q,x,y,m,l,retcon)
+subroutine isolab(g,q,x,y,alpha,beta,m,l,retcon)
 
   use solab
   implicit none
@@ -6,7 +6,9 @@ subroutine isolab(g,q,x,y,m,l,retcon)
   integer, intent(out) :: retcon
   real(kind=8), intent(in)  :: x(m,m), y(m,m)
   real(kind=8), intent(out) :: g(m-l,l), q(l,l)
+  complex(kind=8), intent(out) :: alpha(m)
+  complex(kind=8), intent(out) :: beta(m)
 
-  call zsolab(g,q,x,y,m,l,retcon)
+  call zsolab(g,q,x,y,alpha,beta,m,l,retcon)
 
 end subroutine isolab
