@@ -1,5 +1,6 @@
 try:
     import wheezy
+    from wheezy_dynare_template import wheezy_dynare_template
     from wheezy_template import wheezy_template
 except:
     pass
@@ -13,5 +14,11 @@ except:
 try:
     import cheetah
     from cheetah_template import cheetah_template
+except:
+    pass
+  
+try:
+    import mako
+    from mako_dynare_template import mako_dynare_template
 except:
     pass
\ No newline at end of file
